Index: trunk/psLib/test/astronomy/tst_psTime_01.c
===================================================================
--- trunk/psLib/test/astronomy/tst_psTime_01.c	(revision 3707)
+++ trunk/psLib/test/astronomy/tst_psTime_01.c	(revision 3708)
@@ -18,11 +18,11 @@
  *     M) Convert psTime to tm time
  *     N) Convert tm time to psTime
  *     O) Convert psTime time to LST
  *     P) Free data
  *
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.23 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2005-04-18 23:40:15 $
+ *  @version $Revision: 1.24 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2005-04-19 00:17:06 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -202,10 +202,10 @@
 
 
     // Test O - psTime to LST
     printPositiveTestHeader(stdout, "psTime", "Convert psTime time to LST");
     char *testString2 = "2004-09-10T1:00:00.00Z";
     psTime* testTime2 = NULL;
     testTime2 = psTimeFromISO(testString2);
-    double dblTime = psTimeToLST(testTime2, 1);
+    double dblTime = psTimeToLMST(testTime2, 1);
     printf("LST (rad): %lf\n", dblTime);
     psFree(testTime2);
@@ -18,11 +18,11 @@
  *     M) Convert psTime to tm time
  *     N) Convert tm time to psTime
- *     O) Convert psTime time to LST
+ *     O) Convert psTime time to LMST
  *     P) Free data
  *
@@ -202,10 +202,10 @@
 
 
-    // Test O - psTime to LST
+    // Test O - psTime to LMST
     printPositiveTestHeader(stdout, "psTime", "Convert psTime time to LST");
     char *testString2 = "2004-09-10T1:00:00.00Z";
